# Warning: This package is synchronized with Fedora!

%global glib2_minver 2.54.0

# This requires some distribution work to properly enable
# c.f.: https://github.com/solus-project/linux-driver-management/blob/master/README.md#distro-integration
%bcond_with glx_configuration

%global somajor 1
%global girmajor %{somajor}.0

%global libname %mklibname ldm %{somajor}
%global girname %mklibname ldm-gir %{girmajor}
%global devname %mklibname ldm -d

Name:           linux-driver-management
Version:        1.0.3
Release:        %mkrel 6
Summary:        Generic driver management framework for Linux
Group:          System/Kernel and hardware
License:        LGPLv2+ and CC-BY-SA
URL:            https://github.com/solus-project/linux-driver-management
Source0:        %{url}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Patch1:         0001-Allow-versions-of-libusb-newer-than-1.0.21-to-satisfy-the-dependency.patch

BuildRequires:  meson
BuildRequires:  pkgconfig(glib-2.0) >= %{glib2_minver}
BuildRequires:  pkgconfig(gobject-2.0) >= %{glib2_minver}
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libusb-1.0) >= 1.0.21
BuildRequires:  pkgconfig(libkmod) >= 24
BuildRequires:  pkgconfig(libudev) >= 215
BuildRequires:  pkgconfig(xorg-server)
BuildRequires:  vala-tools
# For tests
BuildRequires:  pkgconfig(check) >= 0.11.0
BuildRequires:  pkgconfig(umockdev-1.0) >= 0.9.0
BuildRequires:  umockdev
# For documentation
BuildRequires:  pkgconfig(gtk-doc)

Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description
Linux Driver Management provides a core library and some tooling
to enable the quick and easy enumeration of system devices,
and functionality to match devices to packages/drivers.

This is designed to be as agnostic as feasible whilst supporting
a wide range of device classes, to provide a building block for
driver management and discovery in Linux distributions.

%package -n %{libname}
Summary:        Libraries for Linux Driver Management
Group:          System/Libraries

%description -n %{libname}
This package contains the libraries for Linux Driver Management
used by other applications.

%package -n %{girname}
Summary:        GObject Introspection interface description for Linux Driver Management
Group:          System/Libraries
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{girname}
This package contains the GObject Introspection interface description for
Linux Driver Management used by other applications.

%package -n %{devname}
Summary:        Development headers and libraries for Linux Driver Management
Group:          Development/C
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{name}-devel%{?_isa} = %{version}-%{release}
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{girname}%{?_isa} = %{version}-%{release}
Recommends:     %{name}-doc

%description -n %{devname}
This package contains headers and libraries for developing applications
that leverage the Linux Driver Management framework.

%package doc
Summary:        Development documentation for Linux Driver Management
Group:          Development/C
BuildArch:      noarch

%description doc
This package contains the developer documentation for integrating
Linux Driver Management into applications.

%if %{with glx_configuration}
%package gdm
Summary:        GDM hook for Linux Driver Management
Group:          Graphical desktop/GNOME
Requires:       gdm
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description gdm
This package contains the hook for GDM to properly set up with graphics
controlled and configured by Linux Driver Management.

%package lightdm
Summary:        LightDM hook for Linux Driver Management
Group:          Graphical desktop/Other
Requires:       lightdm
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description lightdm
This package contains the hook for LightDM to properly set up with graphics
controlled and configured by Linux Driver Management.

%package sddm
Summary:        SDDM hook for Linux Driver Management
Group:          Graphical desktop/KDE
Requires:       sddm
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description sddm
This package contains the hook for SDDM to properly set up with graphics
controlled and configured by Linux Driver Management.
%endif

%prep
%autosetup -p1


%build
%meson %{!?with_glx_configuration:-Dwith-glx-configuration=false}
%meson_build

%install
%meson_install

%check
# umockdev behaves very oddly with the manager test...
( %meson_test ) || :

%files
%license LICENSE.*
%doc README.md
%{_bindir}/*
%{_mandir}/man1/*.1*
%if %{with glx_configuration}
%{_sysconfdir}/xdg/autostart/*
%endif

%files -n %{libname}
%license LICENSE.*
%{_libdir}/libldm.so.%{somajor}
%{_libdir}/libldm.so.%{somajor}.*

%files -n %{girname}
%{_libdir}/girepository-1.0/Ldm-%{girmajor}.typelib

%files -n %{devname}
%{_libdir}/libldm.so
%{_libdir}/pkgconfig/ldm-*.pc
%{_includedir}/%{name}/
%{_datadir}/gir-1.0/Ldm-*.gir
%{_datadir}/vala/vapi/ldm-*

%files doc
%{_datadir}/gtk-doc/html/%{name}/

%if %{with glx_configuration}
%files gdm
%{_datadir}/gdm/greeter/autostart/ldm-session-init.desktop

%files lightdm
%{_datadir}/lightdm/lightdm.conf.d/99-ldm.conf

%files sddm
%{_datadir}/sddm/scripts/Xsetup
%endif



%changelog
* Sat Apr 02 2022 umeabot <umeabot> 1.0.3-6.mga9
+ Revision: 1841072
- Mageia 9 Mass Rebuild

* Sat Feb 15 2020 umeabot <umeabot> 1.0.3-5.mga8
+ Revision: 1525484
- Mageia 8 Mass Rebuild

* Thu Apr 18 2019 umeabot <umeabot> 1.0.3-4.mga7
+ Revision: 1392800
- Rebuild with meson 0.50.1

* Sun Jan 27 2019 daviddavid <daviddavid> 1.0.3-3.mga7
+ Revision: 1361216
- add patch to allow versions of libusb-1.0 newer than 1.0.21 to satisfy the dependency

* Sun Sep 23 2018 umeabot <umeabot> 1.0.3-2.mga7
+ Revision: 1299315
- Mageia 7 Mass Rebuild

* Wed Feb 21 2018 ngompa <ngompa> 1.0.3-1.mga7
+ Revision: 1203865
- Update to 1.0.3

* Sun Jan 28 2018 ngompa <ngompa> 1.0.2-2.mga7
+ Revision: 1197817
- Adapt for Mageia from Fedora
- Switch from Supplements to Recommends for legacy compatibility
- Drop rich Supplements in disabled subpackages as build system spec parser chokes on them
- imported package linux-driver-management


* Sun Jan 28 2018 Neal Gompa <ngompa13@gmail.com> - 1.0.2-1
- Update to 1.0.2
- Drop patches

* Sun Jan 28 2018 Neal Gompa <ngompa13@gmail.com> - 1.0.1-2
- Backport patches to fix build in Fedora

* Sun Jan 28 2018 Neal Gompa <ngompa13@gmail.com> - 1.0.1-1
- Initial packaging
